/*
 *  zzuf - general purpose fuzzer
 *  Copyright (c) 2006 Sam Hocevar <sam@zoy.org>
 *                All Rights Reserved
 *
 *  $Id: debug.h 291 2007-07-06 13:34:38Z sam $
 *
 *  This program is free software. It comes without any warranty, to
 *  the extent permitted by applicable law. You can redistribute it
 *  and/or modify it under the terms of the Do What The Fuck You Want
 *  To Public License, Version 2, as published by Sam Hocevar. See
 *  http://sam.zoy.org/wtfpl/COPYING for more details.
 */

/*
 *  debug.h: debugging support
 */

extern void _zz_debug(const char *format, ...)
       __attribute__((__format__(__printf__, 1, 2)));

#ifdef LIBZZUF
#   define debug _zz_debug
#else
#   define debug(...)
#endif

